@@ -6,7 +6,7 @@ function squirrelmail_plugin_init_disk_quota() {
 }
 
 function disk_quota_version() {
-    return '3.1';
+    return '3.1.1';
 }
 
 if ( !defined('SM_PATH') ) {
